==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-stacked-column-series.js <==
import * as tslib_1 from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
var IgrStackedColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStackedColumnSeries, _super);
    function IgrStackedColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedColumnSeries.prototype.createImplementation = function () {
        return new StackedColumnSeries();
    };
    Object.defineProperty(IgrStackedColumnSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.pw;
        },
        set: function (v) {
            this.i.pw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.px;
        },
        set: function (v) {
            this.i.px = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.ed();
        return (iv);
    };
    return IgrStackedColumnSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedColumnSeries };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-stacked-column-series.js <==
import * as tslib_1 from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
var IgrStackedColumnSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrStackedColumnSeries, _super);
    function IgrStackedColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedColumnSeries.prototype.createImplementation = function () {
        return new StackedColumnSeries();
    };
    Object.defineProperty(IgrStackedColumnSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.p3;
        },
        set: function (v) {
            this.i.p3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrStackedColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.p4;
        },
        set: function (v) {
            this.i.p4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.eg();
        return (iv);
    };
    return IgrStackedColumnSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedColumnSeries };
